@@ -6,10 +6,12 @@
 
 #include <AK/SoundEngine/Common/AkTypes.h>
 #include <AK/SoundEngine/Common/AkSoundEngine.h>
+#include <AK/SoundEngine/Common/AkQueryParameters.h>
 #include <AK/SoundEngine/Common/AkModule.h>
 #include <AK/SoundEngine/Common/AkMemoryMgr.h>
 #include <AK/SoundEngine/Common/IAkStreamMgr.h>
 #include <AK/SoundEngine/Common/AkStreamMgrModule.h>
+#include <AK/MusicEngine/Common/AkMusicEngine.h>
 #include <AK/Tools/Common/AkPlatformFuncs.h>
 
 #ifndef AK_OPTIMIZED
